@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat.h,v 1.35 2005/07/09 05:48:58 ryanl Exp $
+ $Id: battstat.h,v 1.36 2005/08/26 03:45:47 ryanl Exp $
  */
 
 #ifndef _battstat_h_
@@ -165,7 +165,9 @@ void battstat_show_help( ProgressData *battstat, const char *section );
 
 /* power-management.c */
 const char *power_management_getinfo( BatteryStatus *status );
-const char *power_management_initialise( void );
+const char *power_management_initialise( int no_hal );
 void power_management_cleanup( void );
+int power_management_using_hal( void );
+
 
 #endif /* _battstat_h_ */
